Module: MyStuff::Cache

Defined in:
lib/my_stuff/cache.rb,
lib/my_stuff/cache/base.rb,
lib/my_stuff/cache/null_cache.rb,
lib/my_stuff/cache/memory_cache.rb,
lib/my_stuff/cache/memcached_cache.rb

Overview

Simplistic caching module.

You probably want to use ActiveSupport::Cache instead. The two major advantages of this are in Base#get_with_fallback (compared to ActiveSupport::Cache::Store#fetch)

  • you can specify a key pattern

  • it takes a list of IDs, so the implementation might use a multiget (MemcachedCache does this)

See MyStuff::Cache::Base for interface.

Defined Under Namespace

Classes: Base, MemcachedCache, MemoryCache, NullCache